@@ -73,9 +73,6 @@ MAX_CONFIG_DRIVE_SIZE_MB = 64
 # Maximum disk size supported by MBR is 2TB (2 * 1024 * 1024 MB)
 MAX_DISK_SIZE_MB_SUPPORTED_BY_MBR = 2097152
 
-# Limit the memory address space to 1 GiB when running qemu-img
-QEMU_IMG_LIMITS = processutils.ProcessLimits(address_space=1 * units.Gi)
-
 
 def list_partitions(device):
     """Get partitions information from given device.
@@ -108,30 +105,6 @@ def list_partitions(device):
     return result
 
 
-def count_mbr_partitions(device):
-    """Count the number of primary and logical partitions on a MBR
-
-    :param device: The device path.
-    :returns: A tuple with the number of primary partitions and logical
-              partitions.
-    :raise: ValueError if the device does not have a valid MBR partition
-            table.
-    """
-    # -d do not update the kernel table
-    # -s print a summary of the partition table
-    output, err = utils.execute('partprobe', '-d', '-s', device,
-                                run_as_root=True, use_standard_locale=True)
-    if 'msdos' not in output:
-        raise ValueError('The device %s does not have a valid MBR '
-                         'partition table' % device)
-    # Sample output: /dev/vdb: msdos partitions 1 2 3 <5 6 7>
-    # The partitions with number > 4 (and inside <>) are logical partitions
-    output = output.replace('<', '').replace('>', '')
-    partitions = [int(s) for s in output.split() if s.isdigit()]
-
-    return(sum(i < 5 for i in partitions), sum(i > 4 for i in partitions))
-
-
 def get_disk_identifier(dev):
     """Get the disk identifier from the disk being exposed by the ramdisk.
 
@@ -294,15 +267,14 @@ def qemu_img_info(path):
         return imageutils.QemuImgInfo()
 
     out, err = utils.execute('env', 'LC_ALL=C', 'LANG=C',
-                             'qemu-img', 'info', path,
-                             prlimit=QEMU_IMG_LIMITS)
+                             'qemu-img', 'info', path)
     return imageutils.QemuImgInfo(out)
 
 
 def convert_image(source, dest, out_format, run_as_root=False):
     """Convert image to other format."""
     cmd = ('qemu-img', 'convert', '-O', out_format, source, dest)
-    utils.execute(*cmd, run_as_root=run_as_root, prlimit=QEMU_IMG_LIMITS)
+    utils.execute(*cmd, run_as_root=run_as_root)
 
 
 def populate_image(src, dst):
@@ -313,13 +285,6 @@ def populate_image(src, dst):
         convert_image(src, dst, 'raw', True)
 
 
-# TODO(rameshg87): Remove this one-line method and use utils.mkfs
-# directly.
-def mkfs(fs, dev, label=None):
-    """Execute mkfs on a device."""
-    utils.mkfs(fs, dev, label)
-
-
 def block_uuid(dev):
     """Get UUID of a block device."""
     out, _err = utils.execute('blkid', '-s', 'UUID', '-o', 'value', dev,
@@ -522,7 +487,7 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
         # partition.  Create a fat filesystem on it.
         if boot_mode == "uefi" and boot_option == "local":
             efi_system_part = part_dict.get('efi system partition')
-            mkfs(dev=efi_system_part, fs='vfat', label='efi-part')
+            utils.mkfs(fs='vfat', path=efi_system_part, label='efi-part')
 
         if configdrive_part:
             # Copy the configdrive content to the configdrive partition
@@ -542,13 +507,14 @@ def work_on_disk(dev, root_mb, swap_mb, ephemeral_mb, ephemeral_format,
              {'node': node_uuid})
 
     if swap_part:
-        mkfs(dev=swap_part, fs='swap', label='swap1')
+        utils.mkfs(fs='swap', path=swap_part, label='swap1')
         LOG.info(_LI("Swap partition %(swap)s successfully formatted "
                      "for node %(node)s"),
                  {'swap': swap_part, 'node': node_uuid})
 
     if ephemeral_part and not preserve_ephemeral:
-        mkfs(dev=ephemeral_part, fs=ephemeral_format, label="ephemeral0")
+        utils.mkfs(fs=ephemeral_format, path=ephemeral_part,
+                   label="ephemeral0")
         LOG.info(_LI("Ephemeral partition %(ephemeral)s successfully "
                      "formatted for node %(node)s"),
                  {'ephemeral': ephemeral_part, 'node': node_uuid})
@@ -734,23 +700,15 @@ def create_config_drive_partition(node_uuid, device, configdrive):
                 # Check if the disk has 4 partitions. The MBR based disk
                 # cannot have more than 4 partitions.
                 # TODO(stendulker): One can use logical partitions to create
-                # a config drive if there are 3 primary partitions.
+                # a config drive if there are 4 primary partitions.
                 # https://bugs.launchpad.net/ironic/+bug/1561283
-                try:
-                    pp_count, lp_count = count_mbr_partitions(device)
-                except ValueError as e:
-                    raise exception.InstanceDeployFailure(
-                        _('Failed to check the number of primary partitions '
-                          'present on %(dev)s for node %(node)s. Error: '
-                          '%(error)s') % {'dev': device, 'node': node_uuid,
-                                          'error': e})
-                if pp_count > 3:
+                num_parts = len(list_partitions(device))
+                if num_parts > 3:
                     raise exception.InstanceDeployFailure(
                         _('Config drive cannot be created for node %(node)s. '
-                          'Disk (%(dev)s) uses MBR partitioning and already '
-                          'has %(parts)d primary partitions.')
-                        % {'node': node_uuid, 'dev': device,
-                           'parts': pp_count})
+                          'Disk uses MBR partitioning and already has '
+                          '%(parts)d primary partitions.')
+                        % {'node': node_uuid, 'parts': num_parts})
 
                 # Check if disk size exceeds 2TB msdos limit
                 startlimit = '-%dMiB' % MAX_CONFIG_DRIVE_SIZE_MB
@@ -774,7 +732,7 @@ def create_config_drive_partition(node_uuid, device, configdrive):
             if len(new_part) != 1:
                 raise exception.InstanceDeployFailure(
                     _('Disk partitioning failed on device %(device)s. '
-                      'Unable to retrieve config drive partition information.')
+                      'Unable to retrive config drive partition information.')
                     % {'device': device})
 
             if is_iscsi_device(device, node_uuid):
@@ -782,11 +740,6 @@ def create_config_drive_partition(node_uuid, device, configdrive):
             else:
                 config_drive_part = '%s%s' % (device, new_part.pop())
 
-            # NOTE(vdrok): the partition was created successfully, let's wait
-            # for it to appear in /dev.
-            utils.execute('udevadm', 'settle',
-                          '--exit-if-exists=%s' % config_drive_part)
-
         dd(confdrive_file, config_drive_part)
         LOG.info(_LI("Configdrive for node %(node)s successfully "
                      "copied onto partition %(part)s"),
